@@ -1,3 +1,5 @@
+import datetime
+import functools
 import sys
 import os.path
 
@@ -8,10 +10,11 @@ from seesaw.config import realize
 from tornado import ioloop
 
 class Runner(object):
-  def __init__(self, stop_file=None, concurrent_items=1, max_items=None):
+  def __init__(self, stop_file=None, concurrent_items=1, max_items=None, keep_data=False):
     self.pipeline = None
     self.concurrent_items = concurrent_items
     self.max_items = max_items
+    self.keep_data = keep_data
 
     self.item_count = 0
     self.active_items = set()
@@ -89,7 +92,7 @@ class Runner(object):
       while len(self.active_items) < items_required:
         self.item_count += 1
         item_id = "%d-%d" % (id(self), self.item_count)
-        item = Item(pipeline=self.pipeline, item_id=item_id, item_number=self.item_count)
+        item = Item(pipeline=self.pipeline, item_id=item_id, item_number=self.item_count, keep_data=self.keep_data)
         self.on_create_item(self, item)
         self.active_items.add(item)
         self.pipeline.enqueue(item)
@@ -98,6 +101,13 @@ class Runner(object):
     self.on_pipeline_start_item(self, pipeline, item)
 
   def _item_finished(self, pipeline, item):
+    if item.failed:
+      item.log_output("Waiting 10 seconds...")
+      ioloop.IOLoop.instance().add_timeout(datetime.timedelta(seconds=10), functools.partial(self._item_finished_without_delay, pipeline, item))
+    else:
+      self._item_finished_without_delay(pipeline, item)
+
+  def _item_finished_without_delay(self, pipeline, item):
     self.on_pipeline_finish_item(self, pipeline, item)
     self.active_items.remove(item)
     if not self.should_stop():
@@ -106,8 +116,8 @@ class Runner(object):
       self.on_finish(self)
 
 class SimpleRunner(Runner):
-  def __init__(self, pipeline, stop_file=None, concurrent_items=1, max_items=None):
-    Runner.__init__(self, stop_file=stop_file, concurrent_items=concurrent_items, max_items=max_items)
+  def __init__(self, pipeline, stop_file=None, concurrent_items=1, max_items=None, keep_data=False):
+    Runner.__init__(self, stop_file=stop_file, concurrent_items=concurrent_items, max_items=max_items, keep_data=keep_data)
 
     self.set_current_pipeline(pipeline)
     self.on_create_item += self._handle_create_item
@@ -120,6 +130,11 @@ class SimpleRunner(Runner):
   def _stop_ioloop(self, ignored):
     ioloop.IOLoop.instance().stop()
 
+  def forced_stop(self):
+    print "Stopping immediately..."
+    # TODO perhaps the subprocesses should be killed
+    ioloop.IOLoop.instance().stop()
+
   def _handle_create_item(self, ignored, item):
     item.on_output += self._handle_item_output
 
