@@ -36,7 +36,7 @@ class TrackerRequest(Task):
         "%s/%s" % (self.tracker_url, self.tracker_command),
         method="POST",
         headers={"Content-Type": "application/json"},
-        user_agent=("ArchiveTeam Warrior/%s %s" % (seesaw.__version__, seesaw.runner_type)),
+        user_agent=("ArchiveTeam Warrior/%s %s %s" % (seesaw.__version__, seesaw.runner_type, seesaw.warrior_build)).strip(),
         body=json.dumps(self.data(item))
       ), functools.partial(self.handle_response, item))
 
@@ -48,7 +48,7 @@ class TrackerRequest(Task):
       self.process_body(response.body, item)
     else:
       if response.code == 420 or response.code == 429:
-        r = "Tracker rate limiting is in effect. "
+        r = "Tracker rate limiting is active. We don't want to overload the site we're archiving, so we've limited the number of downloads per minute. Please wait... "
       elif response.code == 404:
         r = "No item received. "
       elif response.code == 455:
@@ -73,14 +73,16 @@ class GetItemFromTracker(TrackerRequest):
     self.version = version
 
   def data(self, item):
-    data = {"downloader": realize(self.downloader, item)}
+    data = {"downloader": realize(self.downloader, item), "api_version": "2"}
     if self.version:
       data["version"] = realize(self.version, item)
     return data
 
   def process_body(self, body, item):
-    if len(body.strip()) > 0:
-      item["item_name"] = body.strip()
+    data = json.loads(body)
+    if "item_name" in data:
+      for (k,v) in data.iteritems():
+        item[k] = v
       item.log_output("Received item '%s' from tracker\n" % item["item_name"])
       self.complete_item(item)
     else:
