@@ -134,11 +134,17 @@ class BandwidthMonitor(object):
 
 
 class Warrior(object):
-  def __init__(self, projects_dir, data_dir, warrior_hq_url, real_shutdown=False):
+  def __init__(self, projects_dir, data_dir, warrior_hq_url, real_shutdown=False, keep_data=False):
+    if not os.access(projects_dir, os.W_OK):
+      raise Exception("Couldn't write to projects directory: %s" % projects_dir)
+    if not os.access(data_dir, os.W_OK):
+      raise Exception("Couldn't write to data directory: %s" % data_dir)
+
     self.projects_dir = projects_dir
     self.data_dir = data_dir
     self.warrior_hq_url = warrior_hq_url
     self.real_shutdown = real_shutdown
+    self.keep_data = keep_data
 
     # disable the password prompts
     self.gitenv = dict( os.environ.items() + { 'GIT_ASKPASS': 'echo', 'SSH_ASKPASS': 'echo' }.items() )
@@ -160,7 +166,8 @@ class Warrior(object):
       name="downloader",
       title="Your nickname",
       description="We use your nickname to show your results on our tracker. Letters and numbers only.",
-      regex="^[-_a-zA-Z0-9]{3,30}$"
+      regex="^[-_a-zA-Z0-9]{3,30}$",
+      advanced=False
     )
     self.concurrent_items = NumberConfigValue(
       name="concurrent_items",
@@ -170,17 +177,31 @@ class Warrior(object):
       max=6,
       default=2
     )
+    self.http_username = StringConfigValue(
+      name="http_username",
+      title="HTTP username",
+      description="Enter a username to protect the web interface, or leave empty.",
+      default=""
+    )
+    self.http_password = StringConfigValue(
+      name="http_password",
+      title="HTTP password",
+      description="Enter a password to protect the web interface, or leave empty.",
+      default=""
+    )
 
     self.config_manager = ConfigManager(os.path.join(projects_dir, "config.json"))
     self.config_manager.add(self.warrior_id)
     self.config_manager.add(self.selected_project_config_value)
     self.config_manager.add(self.downloader)
     self.config_manager.add(self.concurrent_items)
+    self.config_manager.add(self.http_username)
+    self.config_manager.add(self.http_password)
 
     self.bandwidth_monitor = BandwidthMonitor("eth0")
     self.bandwidth_monitor.update()
 
-    self.runner = Runner(concurrent_items=self.concurrent_items)
+    self.runner = Runner(concurrent_items=self.concurrent_items, keep_data=self.keep_data)
     self.runner.on_finish += self.handle_runner_finish
 
     self.current_project_name = None
@@ -598,6 +619,7 @@ class Warrior(object):
       self.forced_reboot_timeout = ioloop.IOLoop.instance().add_timeout(datetime.timedelta(days=2), self.forced_reboot)
 
   def forced_reboot(self):
+    print "Stopping immediately..."
     if self.real_shutdown:
       os.system("sudo shutdown -r now")
 
@@ -612,6 +634,11 @@ class Warrior(object):
       if self.real_shutdown:
         os.system("sudo shutdown -h now")
 
+  def forced_stop(self):
+    ioloop.IOLoop.instance().stop()
+    if self.real_shutdown:
+      os.system("sudo shutdown -h now")
+
   def keep_running(self):
     self.shut_down_flag = False
     self.reboot_flag = False
